<?php
/**
 * Tugboat variables
 * https://docs.tugboat.qa/reference/environment-variables/
 *
 * Simplytest progress status list:
 * @see \simplytest_tugboat_status_list()
 *
 * $status_endpoint: The $base_url + route uri + instance id for reporting
 *   status back to the simplytest server.
 */
?># Drupal 7
services:
  # What to call the service hosting the site.
  php:

    # Use PHP 7.2 with Apache
    image: tugboatqa/php:7.2-apache

    # Set this as the default service. This does a few things
    #   1. Clones the git repository into the service container
    #   2. Exposes port 80 to the Tugboat HTTP proxy
    #   3. Routes requests to the preview URL to this service
    default: true
    depends: mysql

    # A set of commands to run while building this service
    commands:
      build:
        # Fetch the right drupal version.
        - composer self-update
        - cd "${DOCROOT}" && git config core.fileMode false
        - cd "${DOCROOT}" && git fetch --all
<?php
if ($project !== 'drupal'):
    $used_version = $drupal_core_version;
else:
    $used_version = $project_version;
endif; ?>
<?php if (substr($used_version, -1) == 'x'): ?>
        - cd "${DOCROOT}" && git reset --hard origin/<?php print $used_version; ?>
<?php else: ?>
        - cd "${DOCROOT}" && git reset --hard <?php print $used_version; ?>
<?php endif; ?>
        # Start the downloads
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_DOWNLOAD;?>
        # Load drupal code base.
<?php if ($project_type == 'Module' or $project_type == 'Theme'): ?>
        - drush -r "${DOCROOT}" dl <?php print $project; ?>-<?php print $project_version; ?> -y
<?php endif; ?>
<?php foreach ($additionals as $additional) { ?>
        - drush -r "${DOCROOT}" dl <?php print $additional; ?> -y
<?php } ?>
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_PATCHING;?>

<?php if (!empty($patches)): ?>
        # Apply patches.
<?php foreach ($patches as $patch) { ?>
        # Download the patch.
        - wget <?php print $patch; ?> --output-document="/tmp/patch.<?php print $instance_id; ?>"
<?php   if ("drupal" == $project): ?>
        - cd "${DOCROOT}" && patch -p1 < "/tmp/patch.<?php print $instance_id; ?>"
<?php   elseif ("Distribution" == $project_type): ?>
        - cd "${DOCROOT}/profiles/contrib/<?php print $project ?>" && patch -p1 < "/tmp/patch.<?php print $instance_id; ?>"
<?php   else: ?>
        - cd "${DOCROOT}/<?php print strtolower($project_type); ?>s/contrib/<?php print $project ?>" && patch -p1 < "/tmp/patch.<?php print $instance_id; ?>"
<?php   endif; ?>
        - rm "/tmp/patch.<?php print $instance_id; ?>"
<?php } ?>
<?php endif; ?>
        - cd "${DOCROOT}" && chmod -R 777 sites/default
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_INSTALLING;?>

<?php if ($perform_install): ?>
        # Update settings file.
        - cd "${DOCROOT}" && echo '$conf["file_private_path"] = "sites/default/files/private";' >> sites/default/settings.php
        # Install drupal.
        - drush -r "${DOCROOT}" si <?php if($project_type == 'Distribution'): print $project; else: print 'standard'; endif; ?> --account-name=admin --account-pass=admin -y
        - cd "${DOCROOT}" && chmod -R 777 sites/default/files
<?php   if ($project_type == 'Module' or $project_type == 'Theme'): ?>
        - drush -r "${DOCROOT}" en <?php print $project; ?> -y
<?php   endif; ?>
<?php   foreach ($additionals as $additional) { ?>
        - drush -r "${DOCROOT}" en <?php print $additional; ?> -y
<?php   } ?>
<?php endif; ?>
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_FINALIZE;?>

  # What to call the service hosting MySQL. This name also acts as the
  # hostname to access the service by from the php service.
  mysql:
    # Use the latest available 5.x version of MySQL
    image: tugboatqa/mysql:5
