# Drupal 8
services:
  # What to call the service hosting the site.
  php:

    # Use PHP 7.2 with Apache
    image: tugboatqa/php:7.2-apache

    # Set this as the default service. This does a few things
    #   1. Clones the git repository into the service container
    #   2. Exposes port 80 to the Tugboat HTTP proxy
    #   3. Routes requests to the preview URL to this service
    default: true
    depends: mysql

    # A set of commands to run while building this service
    commands:

      # Commands that set up the basic preview infrastructure
      build:
        # Fetch the right drupal version.
        - composer self-update
        - cd "${DOCROOT}" && git config core.fileMode false
        - cd "${DOCROOT}" && git fetch --all
<?php
if ($project !== 'drupal'):
  $used_version = $drupal_core_version;
else:
  $used_version = $project_version;
endif; ?>
<?php if (substr($used_version, -1) == 'x'): ?>
        - cd "${DOCROOT}" && git reset --hard origin/<?php print $used_version; ?>
<?php else: ?>
        - cd "${DOCROOT}" && git reset --hard <?php print $used_version; ?>
<?php endif; ?>
        # Start the downloads
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_DOWNLOAD;?>
        # Load drupal code base.
        - composer global require szeidler/composer-patches-cli:~1.0
        - cd "${DOCROOT}" && composer require cweagans/composer-patches:~1.0 --no-update
        - cd "${DOCROOT}" && composer require zaporylie/composer-drupal-optimizations:^1.0 --no-update
        - cd "${DOCROOT}" && composer install --no-ansi --no-dev

<?php if ($project_type == 'Module' or $project_type == 'Theme'): ?>

        - cd "${DOCROOT}" && composer require drupal/<?php print $project; ?>:<?php print $project_version; ?> --no-update

<?php endif; ?>

        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_PATCHING;?>

<?php if (!empty($patches)): ?>

        # Apply patches.
        - cd "${DOCROOT}" && composer patch-enable --file='patches.json'
  <?php foreach ($patches as $patch) { ?>

        - cd "${DOCROOT}" && composer patch-add drupal/<?php
    if ($project !== 'drupal') {
      print $project;
    } else {
      print 'core';
    } ?> "STM patch <?php print time(); ?>" "<?php print $patch; ?>"

  <?php } ?>

<?php endif; ?>

<?php foreach ($additionals as $additional) { ?>

        # Additional.
        - cd "${DOCROOT}" && composer require drupal/<?php print $additional; ?> --no-update

<?php } ?>

        - cd "${DOCROOT}" && composer update --no-ansi --no-dev
        - cd "${DOCROOT}" && chmod -R 777 sites/default
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_INSTALLING;?>

<?php if ($perform_install): ?>
        # Update settings file.
        - cd "${DOCROOT}" && echo 'if (PHP_SAPI === "cli"){ ini_set("memory_limit", "-1"); }' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$settings["file_private_path"] = "sites/default/files/private";' >> sites/default/settings.php
        # Install drupal.
        - drush -r "${DOCROOT}" si <?php if($project_type == 'Distribution'): print $project; else: print 'standard'; endif; ?> --account-name=admin --account-pass=admin -y
        - cd "${DOCROOT}" && chmod -R 777 sites/default/files
<?php   if ($project_type == 'Module' or $project_type == 'Theme'): ?>
        - drush -r "${DOCROOT}" en <?php print $project; ?> -y
<?php   endif; ?>
<?php   foreach ($additionals as $additional) { ?>
        - drush -r "${DOCROOT}" en <?php print $additional; ?> -y
<?php   } ?>
<?php endif; ?>
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_FINALIZE;?>

  # What to call the service hosting MySQL. This name also acts as the
  # hostname to access the service by from the php service.
  mysql:
    # Use the latest available 5.x version of MySQL
    image: tugboatqa/mysql:5
