# Drupal 9
services:
  # What to call the service hosting the site.
  php:

    # Use PHP 7.3 with Apache
    image: tugboatqa/php:7.3-apache

    # Set this as the default service. This does a few things
    #   1. Clones the git repository into the service container
    #   2. Exposes port 80 to the Tugboat HTTP proxy
    #   3. Routes requests to the preview URL to this service
    default: true
    depends: mysql

    # A set of commands to run while building this service
    commands:

      # Commands that set up the basic preview infrastructure
      init:
        # Install mod-rewrite for image styles to work
        - a2enmod headers rewrite

      # Commands that build the site
      build:
        # Fetch the right drupal version.
        - echo "memory_limit = -1" >> /usr/local/etc/php/conf.d/my-php.ini
        - composer self-update
        - rm -rf "${DOCROOT}"
<?php
if ($project !== 'drupal'):
  $used_version = $drupal_core_version;
else:
  $used_version = $project_version;
endif;

$require_version = $used_version;

if (substr($used_version, -1) == 'x'):
  $require_version = $used_version . '@dev';
  $used_version = substr($used_version, 0, -2) . '-dev';
endif;

?>
        # Load drupal code base.
        - composer -n create-project drupal/recommended-project:^<?php print $used_version; ?> stm --no-install
        - cd stm && composer require --update-with-all-dependencies drupal/core-recommended:<?php print $require_version . "\n"; ?>
        - cd stm && composer require --no-update drupal/core-composer-scaffold:<?php print $require_version . "\n"; ?>
        - cd stm && composer require --dev --no-update drupal/dev-dependencies:<?php print"dev-default\n"; ?>
        - composer global require szeidler/composer-patches-cli:~1.0
        - cd stm && composer require cweagans/composer-patches:~1.0 --no-update
        - cd stm && composer require --dev --no-update drush/drush:^10.0
        - cd stm && composer update
        - ln -snf "${TUGBOAT_ROOT}/stm/web" "${DOCROOT}"

        # Start the downloads
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_DOWNLOAD;?>

<?php if ($project_type == 'Module' or $project_type == 'Theme'): ?>
        - cd stm && composer require drupal/<?php print $project; ?>:<?php print $project_version; ?> --no-update
<?php endif; ?>

        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_PATCHING;?>

<?php if (!empty($patches)): ?>
        # Apply patches.
        - cd "${DOCROOT}" && composer patch-enable --file='patches.json'
  <?php foreach ($patches as $patch) { ?>

        - cd "${DOCROOT}" && composer patch-add drupal/<?php
    if ($project !== 'drupal') {
      print $project;
    } else {
      print 'core';
    } ?> "STM patch <?php print time(); ?>" "<?php print $patch; ?>"

  <?php } ?>

<?php endif; ?>

<?php foreach ($additionals as $additional) { ?>
        - cd stm && composer require drupal/<?php print $additional; ?> --no-update
<?php } ?>

        - cd stm && composer update --no-ansi
        - cd "${DOCROOT}" && chmod -R 777 sites/default
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_INSTALLING;?>

        # Finish the instance install.
        - cd "${DOCROOT}" && chmod -R 777 sites/default
        - cd "${DOCROOT}" && rm -f sites/default/settings.php
        - cd "${DOCROOT}" && echo '<?php print '<?php'; ?>' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo 'ini_set("memory_limit", "256M");' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$settings["trusted_host_patterns"] = array("^.+\.tugboat\.qa$",);' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$settings["skip_permissions_hardening"] = TRUE;' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$settings["hash_salt"] = "KjTFgTe4WwbqE0wfGuHIXnNR-_jXvgx6i5tNzvrtGiU";' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$databases["default"]["default"] = [' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "database" => "tugboat", ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "host"     => "mysql", ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "username" => "tugboat", ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "password" => "tugboat", ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "port"     => 3306, ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "driver"   => "mysql", ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '     "prefix"   => "", ' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '];' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$settings["file_private_path"] = "sites/default/files/private";' >> sites/default/settings.php
        - cd "${DOCROOT}" && echo '$settings["config_sync_directory"] = "sites/default/files/sync";' >> sites/default/settings.php
        - cd "${DOCROOT}" && chmod 777 sites/default/settings.php

<?php if ($perform_install): ?>
        # Install drupal.
        - cd "${DOCROOT}" && ../vendor/bin/drush si <?php if($project_type == 'Distribution'): print $project; else: print 'standard'; endif; ?> --db-url=mysql://tugboat:tugboat@mysql:3306/tugboat --account-name=admin --account-pass=admin -y
        - cd "${DOCROOT}" && chmod -R 777 sites/default/files
<?php   if ($project_type == 'Module' or $project_type == 'Theme'): ?>
        - cd "${DOCROOT}" && ../vendor/bin/drush en <?php print $project; ?> -y
<?php   endif; ?>
<?php   foreach ($additionals as $additional) { ?>
        - cd "${DOCROOT}" && ../vendor/bin/drush en <?php print $additional; ?> -y
<?php   } ?>
<?php endif; ?>
        - wget -O/dev/null <?php print $status_endpoint; ?>/<?php print SIMPLYTEST_STATUS_FINALIZE;?>

  # What to call the service hosting MySQL. This name also acts as the
  # hostname to access the service by from the php service.
  mysql:
    # Use the latest available 5.x version of MySQL
    image: tugboatqa/mysql:5
