#!/bin/bash

# @todo Refactor ShellScripts #1836036.

# Make sure we run as root.
if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root!"
   exit 1
fi

# Make sure all arguments are given.
if [[ "$#" -ne 1 ]]; then
  echo "$0 [path to configuration file]"
  exit 1
fi

S_CONFIGURATION=$1

# Make sure all arguments are given.
if [ ! -f $S_CONFIGURATION ]; then
  echo "Given configuration file could not be found."
  exit 1
fi

# Load submission configuration.
source "$S_CONFIGURATION" || exit 1

# Absolute path to script dir.
DIRECTORY="$( cd -P "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

# Load function library.
source "$DIRECTORY/sources/common"

### PREPARE.

# Set state.
s_ste 102

lg "Prepare..."
s_prepare

### DOWNLOAD AND FETCH DEPENDENCIES.

# Set state.
s_ste 103

S_CORE=${S_VERSION:0:1}
S_PROJECT_BRANCH=${S_VERSION: -1}

lg "Running installation with type $S_TYPE core $S_CORE"

# Process the standard way if this is not Drupal 8.
if [[ "8" -ne "$S_CORE" ]]; then
    lg "1a - Downloading Drupal $S_CORE project"
    s_project_download

    lg "Fetch dependencies..."
    s_project_fetch_dependencies

    lg "Download additional projects..."
    s_project_dl_additionals
fi

# Process through composer with Drupal 8, which manages dependencies.
if [[ "8" -eq "$S_CORE" ]]; then
    lg "1b - Downloading Drupal $S_CORE, $S_PROJECT, $S_VERSION, S_PROJECT_BRANCH"
    rm -rf "/home/$S_ID/www"
    cd "/home/$S_ID"

    ### TODO - FIGURE OUT HOW TO DO DISTROS
    #timeout 500 drush dl --destination="/home/$S_ID" --drupal-project-rename="www" --default-major="$S_CORE" "drupal-$S_CORE"
    #if [[ "lightning" -eq "$S_PROJECT" ]]; then
    #    timeout 700 composer create-project acquia/lightning-project:~$S_CORE lightning
    #    ln -s "/home/$S_ID/lightning/docroot" "/home/$S_ID/www"
    #    mkdir "/home/$S_ID/www/themes"
    #else

    # Standard core install.
    if [ "drupal" = "$S_PROJECT" ]; then
        lg "Loading core as the project"

        if [ "x" = "$S_PROJECT_BRANCH" ]; then
            lg "Loading branch $S_VERSION-dev"
            timeout 700 composer create-project drupal/drupal:$S_VERSION-dev www -n
        else
            lg "Loading release $S_VERSION"
            timeout 700 composer create-project drupal/drupal:$S_VERSION www -n
        fi
    else
        lg "Loading core as foundation"
        timeout 500 composer create-project drupal/drupal:~$S_CORE www
    fi

    ### TODO - FIGURE OUT HOW TO DO DISTROS
    #fi
    cd "/home/$S_ID/www"
    S_SUBVERSION=$(echo $S_VERSION| cut -c 5-)
    ### TODO - FIGURE OUT HOW TO DO DISTROS
    #if [[ "lightning" -ne "$S_PROJECT" ]]; then

    # Don't try to reload Drupal, its already loaded.
    if [ "drupal" != "$S_PROJECT" ]; then
        if [ "x" = "$S_PROJECT_BRANCH" ]; then
            lg "Loading project release $S_SUBVERSION-dev"
            timeout 500 composer require "drupal/$S_PROJECT:$S_SUBVERSION-dev" --no-update -n
        else
            lg "Loading project release $S_SUBVERSION"
            timeout 500 composer require "drupal/$S_PROJECT:$S_SUBVERSION" --no-update -n
        fi
    fi

    #fi

    # Additional projects
    for key in "${!S_ADDITIONALS[@]}"
    do
      # Don't try to reload Drupal, its already done.
      if [ "drupal" != "${S_ADDITIONALS[$key]}" ]; then
        timeout 120 composer require "drupal/${S_ADDITIONALS[$key]}" --no-update
      fi
    done

    cd "/home/$S_ID/www"

    # Enable projects to specify patches
    # timeout 120 composer config extra.enable-patching true

    timeout 120 composer config discard-changes true

    # Load all the things
    timeout 500 composer update --with-dependencies -n --no-progress --no-ansi || s_ste 303

    # Enable patching
    #   CLI patch support is not there yet, this wont work.
    #   https://github.com/cweagans/composer-patches/issues/81
    #   Need to do git-based patching for now
    #timeout 120 composer require cweagans/composer-patches

    # Install patches
    # Apply any patches.
    for key in "${!S_PATCHES[@]}"
    do
      # Download the patch.
      timeout 120 wget "${S_PATCHES[$key]}" --output-document="/tmp/patch.$S_ID"
      if [ "drupal" = "$S_PROJECT" ]; then
        lg "Loading core patch ${S_PATCHES[$key]}"
        cd "/home/$S_ID/www"
      else
        if [ "Distribution" = "$S_TYPE" ]; then
          lg "Loading distro patch ${S_PATCHES[$key]}"
          cd "/home/$S_ID/www/profiles/contrib/$S_PROJECT"
        else
          S_TYPE_DIRECTORY="$(echo "$S_TYPE" | tr '[A-Z]' '[a-z]')s"
          lg "Loading module/theme patch ${S_PATCHES[$key]}"
          cd "/home/$S_ID/www/$S_TYPE_DIRECTORY/contrib/$S_PROJECT"
        fi
      fi
      # Try to apply the patch.
      patch -p1 < "/tmp/patch.$S_ID" || s_ste 304
      rm "/tmp/patch.$S_ID"
    done

    cd "/home/$S_ID/www"

    # Make sure a site could be build properly.
    #if [[ ! -d "/home/$S_ID/www" ]]; then
    #  lg "Docroot www directory doesn't exist."
    #  s_ste 302
    #fi
    if [[ -z $(ls "/home/$S_ID/www") ]]; then
      lg "Docroot is empty."
      s_ste 302
    fi
    if [[ ! -r "/home/$S_ID/www/index.php" ]]; then
      lg "No index.php found in docroot."
      s_ste 302
    fi
fi

### INSTALL.
s_ste 104
# NOTE - we call the install function and do conditional logic based on the bypass.
s_project_install
if [ "1" = "$S_BYPASSINSTALL" ]; then
    lg "Bypassing installation..."
else
    lg "Installing project..."

    # Enable module or theme.
    if [ "8" = "$S_CORE" ]; then
     if [ "Module" = "$S_TYPE" ] || [ "Theme" = "$S_TYPE" ]; then
        cd "/home/$S_ID/www"
        timeout 500 drush en $S_PROJECT -y
     fi
    fi
fi

### FINALIZE.
s_ste 105
lg "Finalizing..."

# Add infobar script snippet to index.php.
lg "Adding info snippet..."
s_addsnippet

# Create/Overwrite robots.txt to disallow any indexing.
echo "User-agent: *
Disallow: /
" > "/home/$S_ID/www/robots.txt"

# Make sure all files and directory have the correct group and user.
s_reset_environment_files "$S_ID"

# Enable vhost.
a2ensite $S_ID || s_ste 301

# Reload apache config.
service apache2 reload || service apache2 restart || s_ste 301

# Set a timeout to destroy the environment.
lg "Set timeout to destroy job..."
s_settimeout "$DIRECTORY/destroy.sh $S_ID >>$DIRECTORY/log/$S_ID.log 2>&1" $S_TIMEOUT

### FINISHED
s_ste 106
